==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1CertificateSigningRequestStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.lang.Byte;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1CertificateSigningRequestStatusFluent<A extends V1beta1CertificateSigningRequestStatusFluent<A>> extends Fluent<A>{


    public A withCertificate(byte... certificate);
    public byte[] getCertificate();
    public A addToCertificate(int index,Byte item);
    public A setToCertificate(int index,Byte item);
    public A addToCertificate(Byte... items);
    public A addAllToCertificate(Collection<Byte> items);
    public A removeFromCertificate(Byte... items);
    public A removeAllFromCertificate(Collection<Byte> items);
    public Boolean hasCertificate();
    public A addNewCertificate(byte arg1);
    public A addNewCertificate(String arg1);
    public A addToConditions(int index,V1beta1CertificateSigningRequestCondition item);
    public A setToConditions(int index,V1beta1CertificateSigningRequestCondition item);
    public A addToConditions(V1beta1CertificateSigningRequestCondition... items);
    public A addAllToConditions(Collection<V1beta1CertificateSigningRequestCondition> items);
    public A removeFromConditions(V1beta1CertificateSigningRequestCondition... items);
    public A removeAllFromConditions(Collection<V1beta1CertificateSigningRequestCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CertificateSigningRequestCondition> getConditions();
    public List<V1beta1CertificateSigningRequestCondition> buildConditions();
    public V1beta1CertificateSigningRequestCondition buildCondition(int index);
    public V1beta1CertificateSigningRequestCondition buildFirstCondition();
    public V1beta1CertificateSigningRequestCondition buildLastCondition();
    public V1beta1CertificateSigningRequestCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CertificateSigningRequestConditionBuilder> predicate);
    public A withConditions(List<V1beta1CertificateSigningRequestCondition> conditions);
    public A withConditions(V1beta1CertificateSigningRequestCondition... conditions);
    public Boolean hasConditions();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewCondition();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1CertificateSigningRequestCondition item);
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1CertificateSigningRequestCondition item);
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editLastCondition();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CertificateSigningRequestConditionBuilder> predicate);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CertificateSigningRequestConditionFluent<V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CertificateSigningRequestStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.lang.Byte;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1CertificateSigningRequestStatusFluent<A extends V1beta1CertificateSigningRequestStatusFluent<A>> extends Fluent<A>{


    public A withCertificate(byte... certificate);
    public byte[] getCertificate();
    public A addToCertificate(int index,Byte item);
    public A setToCertificate(int index,Byte item);
    public A addToCertificate(Byte... items);
    public A addAllToCertificate(Collection<Byte> items);
    public A removeFromCertificate(Byte... items);
    public A removeAllFromCertificate(Collection<Byte> items);
    public Boolean hasCertificate();
    public A addNewCertificate(String arg1);
    public A addNewCertificate(byte arg1);
    public A addToConditions(int index,V1beta1CertificateSigningRequestCondition item);
    public A setToConditions(int index,V1beta1CertificateSigningRequestCondition item);
    public A addToConditions(V1beta1CertificateSigningRequestCondition... items);
    public A addAllToConditions(Collection<V1beta1CertificateSigningRequestCondition> items);
    public A removeFromConditions(V1beta1CertificateSigningRequestCondition... items);
    public A removeAllFromConditions(Collection<V1beta1CertificateSigningRequestCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CertificateSigningRequestCondition> getConditions();
    public List<V1beta1CertificateSigningRequestCondition> buildConditions();
    public V1beta1CertificateSigningRequestCondition buildCondition(int index);
    public V1beta1CertificateSigningRequestCondition buildFirstCondition();
    public V1beta1CertificateSigningRequestCondition buildLastCondition();
    public V1beta1CertificateSigningRequestCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CertificateSigningRequestConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CertificateSigningRequestConditionBuilder> predicate);
    public A withConditions(List<V1beta1CertificateSigningRequestCondition> conditions);
    public A withConditions(V1beta1CertificateSigningRequestCondition... conditions);
    public Boolean hasConditions();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewCondition();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1CertificateSigningRequestCondition item);
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1CertificateSigningRequestCondition item);
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editLastCondition();
    public V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CertificateSigningRequestConditionBuilder> predicate);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CertificateSigningRequestConditionFluent<V1beta1CertificateSigningRequestStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
